@@ -17,7 +17,7 @@ class TEDIE(InfoExtractor):
     _TEST = {
         u'url': u'http://www.ted.com/talks/dan_dennett_on_our_consciousness.html',
         u'file': u'102.mp4',
-        u'md5': u'8cd9dfa41ee000ce658fd48fb5d89a61',
+        u'md5': u'2d76ee1576672e0bd8f187513267adf6',
         u'info_dict': {
             u"description": u"md5:c6fa72e6eedbd938c9caf6b2702f5922", 
             u"title": u"Dan Dennett: The illusion of consciousness"
@@ -67,7 +67,7 @@ class TEDIE(InfoExtractor):
         webpage = self._download_webpage(url, video_id, 'Downloading \"%s\" page' % video_name)
         self.report_extraction(video_name)
         # If the url includes the language we get the title translated
-        title = self._html_search_regex(r'<span id="altHeadline" >(?P<title>.*)</span>',
+        title = self._html_search_regex(r'<span .*?id="altHeadline".+?>(?P<title>.*)</span>',
                                         webpage, 'title')
         json_data = self._search_regex(r'<script.*?>var talkDetails = ({.*?})</script>',
                                     webpage, 'json data')
